===============
 API Reference
===============

nti.mailer
==========

.. automodule:: nti.mailer

nti.mailer.interfaces
=====================

.. automodule:: nti.mailer.interfaces

Implementation Details
======================

Default mailer
--------------

.. automodule:: nti.mailer._default_template_mailer

Queue
-----

See :doc:`programs` for information on how these are intended to be used.

.. automodule:: nti.mailer.queue

VERP
----

.. automodule:: nti.mailer._verp
